# Participant Actions

https://docs.aws.amazon.com/connect/latest/APIReference/participant-actions.html

Actions that run in the context of a participant, resulting in experiences like playing prompts, collecting input, or disconnecting.

## Implementation Status

| Block | Status | Notes |
|-------|--------|-------|
| ConnectParticipantWithLexBot | Implemented | Full AWS schema |
| DisconnectParticipant | Implemented | Full AWS schema |
| GetParticipantInput | Implemented | Full AWS schema |
| MessageParticipant | Implemented | Full AWS schema |
| MessageParticipantIteratively | Implemented | Full AWS schema |
| ShowView | Implemented | Full AWS schema |

## Implemented: 6/6
